@@ -6,9 +6,9 @@
 #   scalper and dca bot
 #   more docs and examples
 #   decimal
-#   decorator (or not) for strategies without exit condition (not converted data)
 #   multi-backtest normal calculating(real multi-test, not sum of single tests)
 #   add meta-data in tuner's returns
+#   add "tradingview backtest"
 
 from copy import copy
 from datetime import datetime
@@ -45,13 +45,6 @@ from .plots import QuickTradeGraph
 
 
 class Trader(object):
-    """
-    algo-trading main class.
-    ticker:   |     str      |  ticker/symbol of chart
-    df:       |   dataframe  |  data of chart
-    interval: |     str      |  interval of df.
-
-    """
     _profit_calculate_coef: Union[float, int]
     returns: utils.PREDICT_TYPE_LIST = []
     df: DataFrame
@@ -191,6 +184,9 @@ class Trader(object):
         self._take_profits = take_profits
         return self._stop_losses, self._take_profits
 
+    def multi_trades(self):
+        self.returns, self._credit_leverages = utils.make_multi_trade_returns(self.returns)
+
     def get_heikin_ashi(self, df: DataFrame = DataFrame()) -> DataFrame:
         """
         :param df: dataframe, standard: self.df
@@ -1068,8 +1064,8 @@ class ExampleStrategies(Trader):
         return utils.get_window(self.df[column].values, n)
 
     def find_pip_bar(self,
-                     min_diff_coef: float = 2.0,
-                     body_coef: float = 10.0) -> utils.PREDICT_TYPE_LIST:
+                    min_diff_coef: float = 2.0,
+                    body_coef: float = 10.0) -> utils.PREDICT_TYPE_LIST:
         self.returns = []
         flag = utils.EXIT
         e: int
@@ -1412,10 +1408,10 @@ class ExampleStrategies(Trader):
         return self.returns
 
     def strategy_rsi(self,
-                     minimum: Union[float, int] = 20,
-                     maximum: Union[float, int] = 80,
-                     max_mid: Union[float, int] = 75,
-                     min_mid: Union[float, int] = 35,
+                     minimum: Union[float, int] = 13,
+                     maximum: Union[float, int] = 87,
+                     max_mid: Union[float, int] = 13,
+                     min_mid: Union[float, int] = 87,
                      **rsi_kwargs) -> utils.PREDICT_TYPE_LIST:
         self.returns = []
         rsi = ta.momentum.rsi(close=self.df['Close'], **rsi_kwargs)
@@ -1526,7 +1522,7 @@ class ExampleStrategies(Trader):
 
     def strategy_bollinger(self,
                            plot: bool = True,
-                           to_mid: bool = True,
+                           to_mid: bool = False,
                            *bollinger_args,
                            **bollinger_kwargs) -> utils.PREDICT_TYPE_LIST:
         self.returns = []
@@ -1596,9 +1592,8 @@ class ExampleStrategies(Trader):
                 flag = utils.SELL
             elif bar3price > mid2bar:
                 flag = utils.BUY
-            f2 = flag
             self.returns.append(flag)
-        self.set_open_stop_and_take(stop_loss=points * 2, take_profits=points * 20)
+        self.set_open_stop_and_take(stop_loss=points * 2, take_profit=points * 20)
         self.set_credit_leverages()
         return self.returns
 
