@@ -146,12 +146,12 @@ UPPER_BB_WIDTH: float = 2
 UPPER_BB_ALPHA: float = 1.0
 
 MID_BB_NAME: str = 'mid band'
-MID_BB_COLOR: str = '#00ff7b'
+MID_BB_COLOR: str = '#fff200'
 MID_BB_WIDTH: float = 2
 MID_BB_ALPHA: float = 1.0
 
 LOWER_BB_NAME: str = 'lower band'
-LOWER_BB_COLOR: str = '#00ff7b'
+LOWER_BB_COLOR: str = '#ff0000'
 LOWER_BB_WIDTH: float = 2
 LOWER_BB_ALPHA: float = 1.0
 
@@ -161,7 +161,7 @@ profits: {}
 mean year percentage profit: {}%
 winrate: {}%"""  # .format(Trader.losses, Trader.trades, Trader.profits, Trader.year_profit, Trader.winrate)
 
-__version__: str = "6.4.7"
+__version__: str = "6.5.0"
 __author__: str = 'Vlad Kochetov'
 __credits__: List[str] = [
     "Hemerson Tacon -- Stack overflow",
@@ -457,7 +457,7 @@ def get_diff(price: float,
         return take_profit - price
 
 
-def make_multi_deal_returns(converted_returns: CONVERTED_TYPE_LIST) -> Tuple[PREDICT_TYPE_LIST, List[int]]:
+def make_multi_trade_returns(converted_returns: CONVERTED_TYPE_LIST) -> Tuple[PREDICT_TYPE_LIST, List[int]]:
     if EXIT in converted_returns:
         warn('The use of utils.EXIT is deprecated in this type of strategy. If utils.EXIT is the first item in the sequence, you can replace it with np.nan.')
     result_credlev: List[int] = []
